Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-08-01 20:56:47 +0000
committerStijn Buys <ingar@osirion.org>2008-08-01 20:56:47 +0000
commitd2f36485dd3fbda7c9eb212ac9ffde919af5f8e1 (patch)
treec9c717afa45ea0ca251bc0e9454b7ad9c4898dbd /src/render/render.cc
parent089cb5f96e400d4ab7c9d8041cb51eb8f118d9c1 (diff)
revert renderer camera location, fix r_restart
Diffstat (limited to 'src/render/render.cc')
-rw-r--r--src/render/render.cc7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/render/render.cc b/src/render/render.cc
index c8c6225..e91be23 100644
--- a/src/render/render.cc
+++ b/src/render/render.cc
@@ -113,12 +113,17 @@ void shutdown()
zone->set_sky_texture(0);
}
// clear entity models, this will force a reload
for (core::Entity::Registry::iterator it = core::Entity::registry().begin(); it != core::Entity::registry().end(); it++) {
core::Entity *entity = (*it).second;
if (entity->model())
entity->entity_model = 0;
+
+ if (entity->type() == core::Entity::Globe) {
+ core::EntityGlobe *globe = static_cast<core::EntityGlobe *>(entity);
+ globe->render_texture = 0;
+ }
}
// clear models
@@ -113,12 +113,17 @@ void shutdown()
zone->set_sky_texture(0);
}
- // clear entity models, this will force a reload
+ // clear entity models, and globe textures, this will force a reload
for (core::Entity::Registry::iterator it = core::Entity::registry().begin(); it != core::Entity::registry().end(); it++) {
core::Entity *entity = (*it).second;